.. code-block:: bash

	Usage: cli remote [OPTIONS] COMMAND [ARGS]...
	
	  Set and view remote endpoint.
	
	Options:
	  --help  Show this message and exit.
	
	Commands:
	  add       Set current remote.
	  set-head  Set current default branch.
	  show      Show current remote.
	
	

